package com.ruoyi.frequency.mallevaluate.service;

import com.baomidou.mybatisplus.extension.service.IService;
import com.ruoyi.frequency.mallevaluate.entity.MallEvaluate;

import java.util.List;

/**
 * 商城订单评价Service接口
 *
 * @author liwenlong
 * @date 2024-01-25
 */
public interface MallEvaluateService extends IService<MallEvaluate>
{
    /**
     * 查询商城订单评价
     *
     * @param id 商城订单评价主键
     * @return 商城订单评价
     */
    public MallEvaluate selectMallEvaluateById(Long id);

    /**
     * 查询商城订单评价列表
     *
     * @param mallEvaluate 商城订单评价
     * @return 商城订单评价集合
     */
    public List<MallEvaluate> selectMallEvaluateList(MallEvaluate mallEvaluate);

    /**
     * 新增商城订单评价
     *
     * @param mallEvaluate 商城订单评价
     * @return 结果
     */
    public int insertMallEvaluate(MallEvaluate mallEvaluate);

    /**
     * 修改商城订单评价
     *
     * @param mallEvaluate 商城订单评价
     * @return 结果
     */
    public int updateMallEvaluate(MallEvaluate mallEvaluate);

    /**
     * 批量删除商城订单评价
     *
     * @param ids 需要删除的商城订单评价主键集合
     * @return 结果
     */
    public int deleteMallEvaluateByIds(Long[] ids,Integer delFlag);

}
